#!/usr/bin/env python

# standard library imports

# third party related imports

# local library imports


class Url(object):

    def __init__(self, url):

        self.proto = 'http://'
        self.url = url


#!/usr/bin/env python

# standard library imports

# third party related imports

# local library imports


class Mail(object):

    def __init__(self, mail):

        self.proto = 'mailto:'
        self.url = mail


#!/usr/bin/env python

# standard library imports
import re

# third party related imports

# local library imports
from autolink_py.component import Mail, Url
from autolink_py.values.replace_type import ReplaceType
from autolink_py.utils.helper import (
    escape_url,
    force_unicode,
    re_find
)
from autolink_py.values import (
    combined_re,
    proto_re,
    punct_re
)


class AutoLinker(object):

    def __init__(self):

        self.replaced_type = None

    def linkify(self, text, replaced_type=None):

        """
        Convert URL-like and email-like strings into links.
        """

        self.replaced_type = replaced_type

        # Make replaces
        return re.sub(combined_re, self._repl, force_unicode(text))

    def _repl(self, match):

        """
        Currently, the replace_type can be 'HTML' or 'MARKDOWN', if you
        want to replace url with other format, you can inherit class
        AutoLinker and implement link_repl to customize.
        """

        matches = match.groupdict()
        if matches['url']:
            instance = Url(matches['url'])
        else:
            instance = Mail(matches['email'])

        opening, url, closing = self.separate_parentheses(instance.url)
        punct = re_find(punct_re, url)

        if punct:
            url = url[:-len(punct)]

        if re.search(proto_re, url):
            link = text = url
        else:
            link = instance.proto + url
            text = url

        if self.replaced_type == ReplaceType.HTML:
            replaced_url = self.replace_url(text, link)

        elif self.replaced_type == ReplaceType.MARKDOWN:
            replaced_url = self.replace_url(text, link)

        else:
            replaced_url = self.replace_url(text, link)

        repl = u'{0!s}{1!s}{2!s}{3!s}'
        return repl.format(opening, replaced_url, punct, closing)

    def separate_parentheses(self, s):
        start = re_find(r'^\(*', s)
        end = re_find(r'\)*$', s)
        n = min(len(start), len(end))
        if n:
            return s[:n], s[n:-n], s[-n:]
        else:
            return '', s, ''

    def replace_url(self, text, url):

        """
        replace url into customize format. If you want to customize new format
        for the url, you need to create a new class inherit AutoLinker and
        rewrite replace_url function
        """

        if self.replaced_type == ReplaceType.HTML:

            href = escape_url(url)
            return u'<a href="{0!}">{1}</a>'.format(href, text)

        elif self.replaced_type == ReplaceType.MARKDOWN:

            return u'[{0}]({1})'.format(text, url)

        else:
            raise NotImplementedError



#!/usr/bin/env python

from os.path import exists
from setuptools import setup, find_packages

from autolink_py import __version__

setup(
    name='autolink_py',
    version=__version__,
    # Your name & email here
    author='Tzeng',
    author_email='tseng0211@gmail.com',
    # If you had autolink_py.tests, you would also include that in this list
    packages=find_packages(),
    # Any executable scripts, typically in 'bin'. E.g 'bin/do-something.py'
    scripts=[],
    # REQUIRED: Your project's URL
    url='https://github.com/joanne-tseng/autolink_py',
    # Put your license here. See LICENSE.txt for more information
    license='',
    # Put a nice one-liner description here
    description='',
    long_description=open('README.md').read() if exists("README.md") else "",
    # Any requirements here, e.g. "Django >= 1.1.1"
    install_requires=[
        
    ],
)



#!/usr/bin/env python

# standard library imports

# third party related imports
import re
import six

# local library imports


def escape_url(url):

    return url.replace('&', '&amp;')


def force_unicode(s, encoding='utf-8', errors='strict'):

    """
    Similar to smart_text, except that lazy instances are resolved to
    strings, rather than kept as lazy objects.
    """

    # Handle the common case first, saves 30-40% when s is an instance of
    # six.text_type. This function gets called often in that setting.

    if isinstance(s, six.text_type):
        return s

    if not isinstance(s, six.string_types):

        if six.PY3:
            if isinstance(s, bytes):
                s = six.text_type(s, encoding, errors)
            else:
                s = six.text_type(s)
        else:
            s = six.text_type(bytes(s), encoding, errors)

    else:
        
        # Note: We use .decode() here, instead of six.text_type(s,
        # encoding, errors), so that if s is a SafeBytes, it ends up being
        # a SafeText at the end.

        s = s.decode(encoding, errors)
    return s


def re_find(regex, s):

    m = re.search(regex, s)
    if m:
        return m.group()